import { select, csv, scaleLinear, scaleTime, extent, axisLeft, axisBottom, line, curveBasis } from 'd3';

// Select the SVG element from the DOM
const svg = select('svg');

// Define the dimensions of the SVG element
const width = +svg.attr('width');
const height = +svg.attr('height');

// Define the rendering function for the line chart
const render = data => {

  // Define the accessor functions for the X and Y values
  const xValue = d => d.Year;
  const yValue = d => d.Average_majority_prime_rate;

  // Define the labels for the X and Y axes
  const xAxisLabel = 'Year';
  const yAxisLabel = 'Average Prime Lending Rate';

  // Define the styles and layout for the chart
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  // Create the X and Y scales
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  // Create the X and Y axes
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);

  // Append the X and Y axes to the chart
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  const yAxisLabelG = g.append('g')
    .attr('class', 'y-axis-label')
    .attr('transform', `translate(-70,${innerHeight / 2})`);
		
  yAxisLabelG.append('text')
    .attr('class', 'axis-label')								
    .attr('fill', 'black')
    .attr('text-anchor', 'middle')
    .attr('transform', `rotate(-90)`)
		.text(yAxisLabel);
  
  const yAxisG = g.append('g')
    .call(yAxis)
    .selectAll('.domain')
    .remove();

  const xAxisG = g.append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('y', 50)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black')
    .text(xAxisLabel);

  // Create the line generator function
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
    .curve(curveBasis);

  // Append the line to the chart
  g.append('path')
    .attr('class', 'line-path')
    .attr('d', lineGenerator(data));

};

//geist data is linked 
csv('https://gist.githubusercontent.com/senthilrajendran1/d71291fc85003055166eed3b8421d42b/raw/e6b5b9ebdb5da52b4e9dc5a36dda6488b547591a/historical_prime_rate.csv')
  .then(data => {
    data.forEach(d => {
      d.Average_majority_prime_rate = +d.Average_majority_prime_rate;
      d.Year = +d.Year;
    });
    render(data);
  })
  .catch(error => {
    console.log('Error loading data:', error);
  });